@@ -14,7 +14,7 @@ pub use {
 use {
     crate::{
         app::{App, AppContext},
-        conf::Conf,
+        conf::{Conf, write_default_conf_in},
         display,
         errors::ProgramError,
         launchable::Launchable,
@@ -41,12 +41,17 @@ pub fn run() -> Result<Option<Launchable>, ProgramError> {
 
     // parse the launch arguments we got from cli
     let args = Args::parse();
+    let mut must_quit = false;
+
+    if let Some(dir) = &args.write_default_conf {
+        write_default_conf_in(dir)?;
+        must_quit = true;
+    }
 
     // read the install related arguments
     let install_args = InstallLaunchArgs::from(&args)?;
 
     // execute installation things required by launch args
-    let mut must_quit = false;
     if let Some(state) = install_args.set_install_state {
         write_state(state)?;
         must_quit = true;
@@ -88,11 +93,10 @@ pub fn run() -> Result<Option<Launchable>, ProgramError> {
     };
     debug!("config: {:#?}", &config);
 
-
     // verb store is completed from the config file(s)
     let verb_store = VerbStore::new(&mut config)?;
 
-    let context = AppContext::from(args, verb_store, &config)?;
+    let mut context = AppContext::from(args, verb_store, &config)?;
 
     #[cfg(unix)]
     if let Some(server_name) = &context.launch_args.send {
@@ -101,11 +105,13 @@ pub fn run() -> Result<Option<Launchable>, ProgramError> {
             net::{Client, Message},
         };
         let client = Client::new(server_name);
-        if let Some(seq) = &context.launch_args.commands {
+        if let Some(seq) = &context.launch_args.cmd {
             let message = Message::Sequence(Sequence::new_local(seq.to_string()));
             client.send(&message)?;
         } else if !context.launch_args.get_root {
-            let message = Message::Command(format!(":focus {}", context.initial_root.to_string_lossy()));
+            let message = Message::Command(
+                format!(":focus {}", context.initial_root.to_string_lossy())
+            );
             client.send(&message)?;
         };
         if context.launch_args.get_root {
@@ -121,7 +127,7 @@ pub fn run() -> Result<Option<Launchable>, ProgramError> {
     if context.capture_mouse {
         w.queue(EnableMouseCapture)?;
     }
-    let r = app.run(&mut w, &context, &config);
+    let r = app.run(&mut w, &mut context, &config);
     if context.capture_mouse {
         w.queue(DisableMouseCapture)?;
     }
